==> qdl-plugins-sendvid_0.0.2.tar.gz: qdl-plugins-sendvid-0.0.2/qdl2-sendvid.js <==
/*
 * Copyright (C) 2016 Stuart Howarth <showarth@marxoft.co.uk>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

var request = null;

function checkUrl(url) {
    if (url.substring(url.length - 4) == ".mp4") {
        url = url.substring(0, url.length - 4);
    }
    
    request = new XMLHttpRequest();
    request.onreadystatechange = function () {
        if (request.readyState == 4) {
            try {
                var fileName = request.responseText.split("og:title\" content=\"")[1].split("\"")[0];
                
                if (fileName) {
                    urlChecked({"url": url, "fileName": fileName + ".mp4"});
                }
                else {
                    error(qsTr("File not found"));
                }
            }
            catch(err) {
                error(err);
            }
        }
    }

    request.open("GET", url);
    request.send();
}

function getDownloadRequest(url) {
    if (url.substring(url.length - 4) == ".mp4") {
        downloadRequest({"url": url});
        return;
    }
    
    request = new XMLHttpRequest();
    request.onreadystatechange = function () {
        if (request.readyState == 4) {
            try {
                var videoUrl = request.responseText.split("og:video\" content=\"")[1].split("\"")[0];

                if (videoUrl) {
                    downloadRequest({"url": videoUrl});
                }
                else {
                    error(qsTr("Unknown error"));
                }
            }
            catch(err) {
                error(err);
            }
        }
    }

    request.open("GET", url);
    request.send();
}

function cancelCurrentOperation() {
    if (request) {
        request.abort();
    }

    return true;
}

==> qdl-plugins-sendvid_0.0.3.tar.gz: qdl-plugins-sendvid-0.0.3/qdl2-sendvid.js <==
/*
 * Copyright (C) 2016 Stuart Howarth <showarth@marxoft.co.uk>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

var request = null;

function checkUrl(url) {
    if (url.substring(url.length - 4) == ".mp4") {
        url = url.substring(0, url.length - 4);
    }
    
    request = new XMLHttpRequest();
    request.onreadystatechange = function () {
        if (request.readyState == 4) {
            try {
                var fileName = request.responseText.split("og:title\" content=\"")[1].split("\"")[0];
                
                if (fileName) {
                    urlChecked(new UrlResult(url, fileName + ".mp4"));
                }
                else {
                    error(qsTr("File not found"));
                }
            }
            catch(err) {
                error(err);
            }
        }
    }

    request.open("GET", url);
    request.send();
}

function getDownloadRequest(url) {
    if (url.substring(url.length - 4) == ".mp4") {
        downloadRequest({"url": url});
        return;
    }
    
    request = new XMLHttpRequest();
    request.onreadystatechange = function () {
        if (request.readyState == 4) {
            try {
                var videoUrl = request.responseText.split("og:video\" content=\"")[1].split("\"")[0];

                if (videoUrl) {
                    downloadRequest(new NetworkRequest(videoUrl));
                }
                else {
                    error(qsTr("Unknown error"));
                }
            }
            catch(err) {
                error(err);
            }
        }
    }

    request.open("GET", url);
    request.send();
}

function cancelCurrentOperation() {
    if (request) {
        request.abort();
    }

    return true;
}
